## OPUS greenNet python API wrapper

## Supported Devices
### Switch
- [x] OPUS BRiDGE 1 Channel
- [x] OPUS BRiDGE 2 Channel
- [x] OPUS BRiDGE Roller shutter / Venetian blind 
- [ ] OPUS BRiDGE 1 channel, 16A 
- [ ] OPUS actuator "Professional" round 

### Monetoring
- [ ] OPUS smoke detector 
- [ ] OPUS door/window contact 
- [ ] Any Motion sensor
- [ ] Any Water detector
- [ ] Any Handle sensor
- [ ] Any Temperature / Heat sensor